@@ -1,3 +1,7 @@
+#
+#  $Id: ReadKey.pm,v 1.4 2002/01/28 18:40:18 gellyfish Exp $
+# 
+
 =head1 NAME
 
 Term::ReadKey - A perl module for simple terminal control
@@ -46,13 +50,13 @@ values:
     raw
     ultra-raw
 
-These functions are automatically applied to the STDIN handle if no other
-handle is supplied. Modes 0 and 5 have some special properties worth
-mentioning: not only will mode 0 restore original settings, but it cause the
-next ReadMode call to save a new set of default settings. Mode 5 is similar
-to mode 4, except no CR/LF translation is performed, and if possible, parity
-will be disabled (only if not being used by the terminal, however. It is no different
-from mode 4 under Windows.)
+These functions are automatically applied to the STDIN handle if no
+other handle is supplied. Modes 0 and 5 have some special properties
+worth mentioning: not only will mode 0 restore original settings, but it
+cause the next ReadMode call to save a new set of default settings. Mode
+5 is similar to mode 4, except no CR/LF translation is performed, and if
+possible, parity will be disabled (only if not being used by the terminal,
+however. It is no different from mode 4 under Windows.)
 
 If you are executing another program that may be changing the terminal mode,
 you will either want to say
@@ -200,11 +204,14 @@ This call does nothing under Windows.
 
 Kenneth Albanowski <kjahds@kjahds.com>
 
+Currently maintained by Jonathan Stowe <jns@gellyfish.com>
+
 =cut
 
 package Term::ReadKey;
 
-$VERSION = '2.16';
+
+$VERSION = '2.18';
 
 require Exporter;
 require AutoLoader;
